@@ -5,7 +5,6 @@ pub use self::{
 };
 use anyhow::Result;
 use futures::FutureExt;
-use ignore::Walk;
 use std::{
 	future::Future,
 	path::{Path, PathBuf},
@@ -18,7 +17,7 @@ pub mod embed;
 mod hash;
 pub mod watchserve;
 
-pub enum Page {
+pub enum Route {
 	Static {
 		paths: Option<Box<dyn 'static + Send + Sync + Fn() -> Vec<String>>>,
 		handler: Box<dyn 'static + Send + Sync + Fn(String) -> String>,
@@ -35,36 +34,36 @@ pub type DynamicHandler = Box<
 pub type DynamicHandlerOutput<'a> =
 	Pin<Box<dyn 'a + Send + Future<Output = Result<http::Response<hyper::Body>>>>>;
 
-impl Page {
-	pub fn new_static<H>(handler: H) -> Page
+impl Route {
+	pub fn new_static<H>(handler: H) -> Route
 	where
 		H: 'static + Send + Sync + Fn(String) -> String,
 	{
-		Page::Static {
+		Route::Static {
 			paths: None,
 			handler: Box::new(handler),
 		}
 	}
 
-	pub fn new_static_with_paths<P, H>(paths: P, handler: H) -> Page
+	pub fn new_static_with_paths<P, H>(paths: P, handler: H) -> Route
 	where
 		P: 'static + Send + Sync + Fn() -> Vec<String>,
 		H: 'static + Send + Sync + Fn(String) -> String,
 	{
-		Page::Static {
+		Route::Static {
 			paths: Some(Box::new(paths)),
 			handler: Box::new(handler),
 		}
 	}
 
-	pub fn new_dynamic<H>(handler: H) -> Page
+	pub fn new_dynamic<H>(handler: H) -> Route
 	where
 		H: 'static
 			+ Send
 			+ Sync
 			+ for<'a> Fn(&'a mut http::Request<hyper::Body>) -> DynamicHandlerOutput<'a>,
 	{
-		Page::Dynamic {
+		Route::Dynamic {
 			handler: Box::new(handler),
 		}
 	}
@@ -74,7 +73,7 @@ impl Page {
 		request: &'a mut http::Request<hyper::Body>,
 	) -> DynamicHandlerOutput<'a> {
 		match self {
-			Page::Static { handler, .. } => {
+			Route::Static { handler, .. } => {
 				let html = handler(request.uri().path().to_owned());
 				async {
 					let response = http::Response::builder()
@@ -85,7 +84,7 @@ impl Page {
 				}
 				.boxed()
 			}
-			Page::Dynamic { handler } => handler(request),
+			Route::Dynamic { handler } => handler(request),
 		}
 	}
 }
@@ -135,12 +134,12 @@ pub struct DebugSunfish {
 pub struct ReleaseSunfish {
 	pub embedded_dir: EmbeddedDirectory,
 	pub routes_handler: RoutesHandler,
-	pub routes: Vec<Route>,
+	pub routes: Vec<RouteInitializer>,
 }
 
-pub struct Route {
+pub struct RouteInitializer {
 	pub path_with_placeholders: String,
-	pub init: fn() -> Page,
+	pub init: fn() -> Route,
 }
 
 impl Sunfish {
@@ -153,13 +152,6 @@ impl Sunfish {
 			Sunfish::Release(s) => s.handle(request).await,
 		}
 	}
-
-	pub fn export(&self, out_dir: &Path, dist_path: &Path) -> Result<()> {
-		match self {
-			Sunfish::Debug(_) => unimplemented!(),
-			Sunfish::Release(s) => s.export(out_dir, dist_path),
-		}
-	}
 }
 
 impl DebugSunfish {
@@ -179,7 +171,7 @@ impl DebugSunfish {
 		&self,
 		request: &mut http::Request<hyper::Body>,
 	) -> Result<Option<http::Response<hyper::Body>>> {
-		Ok(self.routes_handler.as_ref()(request).await?)
+		self.routes_handler.as_ref()(request).await
 	}
 
 	async fn serve_asset(
@@ -228,7 +220,7 @@ impl ReleaseSunfish {
 		&self,
 		request: &mut http::Request<hyper::Body>,
 	) -> Result<Option<http::Response<hyper::Body>>> {
-		Ok(self.routes_handler.as_ref()(request).await?)
+		self.routes_handler.as_ref()(request).await
 	}
 
 	async fn serve_asset(
@@ -243,7 +235,7 @@ impl ReleaseSunfish {
 			return Ok(None);
 		}
 		let path = Path::new(path.strip_prefix('/').unwrap());
-		let file = if let Some(file) = self.embedded_dir.read(&path) {
+		let file = if let Some(file) = self.embedded_dir.read(path) {
 			file
 		} else {
 			return Ok(None);
@@ -251,7 +243,7 @@ impl ReleaseSunfish {
 		let data = file.data;
 		let hash = &file.hash;
 		let mut response = http::Response::builder();
-		if let Some(content_type) = content_type(&path) {
+		if let Some(content_type) = content_type(path) {
 			response = response.header(http::header::CONTENT_TYPE, content_type);
 		}
 		response = response.header(http::header::ETAG, hash);
@@ -266,51 +258,6 @@ impl ReleaseSunfish {
 		let response = response.body(hyper::Body::from(data)).unwrap();
 		Ok(Some(response))
 	}
-
-	pub fn export(&self, out_dir: &Path, dist_path: &Path) -> Result<()> {
-		let output_path = out_dir.join("output");
-		// Create a new directory at dist_path.
-		if std::fs::metadata(&dist_path).is_ok() {
-			std::fs::remove_dir_all(&dist_path)?;
-		}
-		std::fs::create_dir_all(&dist_path)?;
-		// Copy the contents of the out_dir to the dist_path.
-		for entry in Walk::new(&output_path) {
-			let entry = entry.unwrap();
-			let input_path = entry.path();
-			if !input_path.is_file() {
-				continue;
-			}
-			let path = input_path.strip_prefix(&output_path).unwrap();
-			let output_path = dist_path.join(path);
-			std::fs::create_dir_all(output_path.parent().unwrap()).unwrap();
-			std::fs::copy(&input_path, &output_path).unwrap();
-		}
-		// Render and write the html for each page.
-		for route in self.routes.iter() {
-			match (route.init)() {
-				Page::Static { paths, handler } => {
-					let paths = paths
-						.map(|paths| paths())
-						.unwrap_or_else(|| vec![route.path_with_placeholders.clone()]);
-					for path in paths {
-						let output_html_path = match path.as_str() {
-							"/" => "/index.html".to_owned(),
-							path if path.ends_with('/') => format!("{}index.html", path),
-							path => format!("{}.html", path),
-						};
-						let output_html_path =
-							dist_path.join(&output_html_path.strip_prefix('/').unwrap());
-						let html = handler(path);
-						std::fs::create_dir_all(output_html_path.parent().unwrap()).unwrap();
-						std::fs::write(&output_html_path, html)?;
-					}
-				}
-				Page::Dynamic { .. } => continue,
-			}
-		}
-		Ok(())
-	}
 }
 
 fn content_type(path: &std::path::Path) -> Option<&'static str> {
